## <img src="https://cdn2.hubspot.net/hubfs/100006/images/super_square_logo_3.png" title="SeleniumBase" height="32"> CHANGELOG

### See: [SeleniumBase/releases](https://github.com/seleniumbase/SeleniumBase/releases)
